@@ -1,7 +1,7 @@
-pub use cli_interface::*;
+pub use args::*;
 pub use desktop_args::*;
 pub use web_args::*;
 
-mod cli_interface;
+mod args;
 mod desktop_args;
 mod web_args;
